@@ -13,7 +13,7 @@ use Moo;
 with 'Dancer2::Core::Role::SessionFactory';
 use namespace::clean;
 
-our $VERSION = '0.102';
+our $VERSION = '0.110';
 
 =head1 NAME
 
@@ -21,7 +21,7 @@ Dancer2::Session::DBIC - DBIx::Class session engine for Dancer2
 
 =head1 VERSION
 
-0.102
+0.110
 
 =head1 DESCRIPTION
 
@@ -318,6 +318,18 @@ sub _retrieve {
     return $session;
 }
 
+=head2 _change_id( $old_id, $new_id )
+
+Change ID of session with C<$old_id> to <$new_id>.
+
+=cut
+
+sub _change_id {
+    my ( $self, $old_id, $new_id ) = @_;
+
+    $self->_rset->search( { $self->id_column => $old_id } )
+      ->update( { $self->id_column => $new_id } );
+}
 
 =head2 _destroy()
 
@@ -447,7 +459,8 @@ Based on code from L<Dancer::Session::DBI> written by James Aitken
 and code from L<Dancer::Plugin::DBIC> written by Naveed Massjouni.
 
 Peter Mottram, support for JSON, YAML, Sereal and custom
-serializers, GH #8, #9, #11, #12.
+serializers, GH #8, #9, #11, #12. Also for adding _change_id
+method and accompanying tests.
 
 Rory Zweistra, GH #9.
 
